declare module BA.Ui.Controls {
    class TokenBoxEvents {
        static TokenBoxTokensChanged(s: ASPxClientTokenBox, e: ASPxClientEventArgs): void;
        static TokenBoxTokensInit(sender: any, e: any): void;
        static OnLinksTokenboxInit(s: any, e: any): void;
        static OnKeyDown(s: any, e: any): void;
        /******* SORTABLE TOKENBOX STUFF BELOW *******/
        static GetControl(name: string): BASortableTokenBoxControl;
        static GetHiddenControl(name: string): ASPxClientTextBox;
        /**
         * Initializes the sortable tokenbox control. As the sortable tokenbox is a simple devex label control, this
         * method can add several functions to the label object that help us in managing the tokens of the tokenbox.
         * In addition, it initializes drag and drop using dragula.js if applicable.
         * @param sender the "TokenBox" control
         * @param evt the init event object
         */
        static InitSortableTokenbox(sender: any, evt: any): void;
        private static UpdateHiddenCompanionIfChanged;
        static SortableTokenboxOpenerClicked(dlgParameters: CustomData, senderName: string): void;
        static SortableTokenboxOpenDialog(context: Window, onFinished: Function, afterStart: Function, controlName: string, additionalParameters: string): void;
        /**
         * Private helper function that creates html from the given token, that can be added to the control.
         *
         * @param token The token-data to be created
         * @param control The aspx label control representing the tokenbox control
         * @param readOnly true, if tokens may not be removed
         * @param sortable true, if tokens may be moved using drag and drop
         */
        private static CreateTokenHtml;
        /**
        * Invoked, when a token is double clicked. Tries to open the referenced record.
        *
        * @param oid The oid of the record to open
        * @param ormType The orm type of the record to open
        */
        static TryOpen(oid: string, ormType: string): void;
        /**
         * Creates a token object from the given grid view row (html element).
         *
         * @param row HTMLElement of some row of a grid view that displays records.
         */
        private static CreateTokenFromRow;
        /**
         * Private helper function that is called when the contents of the control are changed. It sets the current tab
         * as dirty and refreshes configured refresh groups.
         *
         * @param control The aspx label control representing the tokenbox control
         */
        private static OnChanged;
        /**
         * Private helper function that html-encodes the given string, thus turning special characters into entities.
         *
         * @param text text to be encoded
         */
        private static EncodeHTML;
    }
    /** Class that represents a token of the sortable token box */
    class Token {
        Oid: string;
        Title: string;
        Type: string;
        constructor(Oid: string, Title: string, Type: string);
    }
}
