declare module BA.Ui.Dialog {
    /**
     *  Contains all sorts of event functions that are called in context with the import configuration dialog.
     */
    class ImportJobDialogEvents {
        /**
         * Encodes non-ascii characters of a given string into html entities.
         *
         * @param value string to encode
         * @returns encoded string
         */
        private static encodeHtml;
        /**
         * Called when a file entry on the list of files is double clicked.
         * Will open a message box with detailed information about the selected file.
         */
        static FileGridDblClick(sender: ASPxClientGridView, evt: ASPxClientGridViewRowClickEventArgs): void;
        /**
         * Called when the 'Delete selected file' link is clicked.
         * Calls a controller function in order to delete the selected file from the import directory.
         */
        static DeleteSelectedFiles(sender: any, evt: any): void;
        /**
         * Called when the 'Delete all files' link is clicked.
         * Calls a controller function in order to delete all files from the import directory.
         */
        static DeleteAllFiles(sender: any, evt: any): void;
        /**
         * Called when a file upload by the user has finished.
         * Refreshes the list of files.
         */
        static ClientSideEventFilesUploadComplete(sender: any, evt: any): void;
        /**
         * Called when the save button on the dialog is clicked.
         * Under certain circumstances asks the user for confirmation to re-schedule the current import configuration.
         */
        static OnSave(sender: BADialogButton, evt: ASPxClientButtonClickEventArgs): void;
        static OnDelete(sender: BADialogButton, evt: ASPxClientButtonClickEventArgs): void;
        static OnImportDirPathChanged(sender: ASPxClientTextEdit, evt: ASPxClientEventArgs): void;
        static OnImportDirGotFocus(sender: any, evt: ASPxClientEventArgs): void;
        static OnImportDirLostFocus(sender: any, evt: ASPxClientEventArgs): void;
    }
}
